Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(792)

Unified Diff: net/spdy/spdy_http_stream_spdy2_unittest.cc

Issue 9617039: Change Origin bound certs -> Domain bound certs. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: rename all the things Created 8 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: net/spdy/spdy_http_stream_spdy2_unittest.cc
diff --git a/net/spdy/spdy_http_stream_spdy2_unittest.cc b/net/spdy/spdy_http_stream_spdy2_unittest.cc
index 836d50dcb4497a2f5206beebc30f09ede7b757e0..77d33dc3f0cd603cb9cba571cc04dec2641127c1 100644
--- a/net/spdy/spdy_http_stream_spdy2_unittest.cc
+++ b/net/spdy/spdy_http_stream_spdy2_unittest.cc
@@ -63,7 +63,7 @@ class SpdyHttpStreamSpdy2Test : public testing::Test {
}
void TestSendCredentials(
- OriginBoundCertService* obc_service,
+ ServerBoundCertService* sbc_service,
wtc 2012/03/15 23:46:38 Let's rename sbc_service to server_bound_cert_serv
mattm 2012/03/16 22:22:00 Done.
const std::string& cert,
const std::string& proof,
SSLClientCertType type);
@@ -247,8 +247,8 @@ TEST_F(SpdyHttpStreamSpdy2Test, SpdyURLTest) {
namespace {
-void GetECOriginBoundCertAndProof(const std::string& origin,
- OriginBoundCertService* obc_service,
+void GetECServerBoundCertAndProof(const std::string& origin,
+ ServerBoundCertService* sbc_service,
std::string* cert,
std::string* proof) {
TestCompletionCallback callback;
@@ -256,8 +256,8 @@ void GetECOriginBoundCertAndProof(const std::string& origin,
requested_cert_types.push_back(CLIENT_CERT_ECDSA_SIGN);
SSLClientCertType cert_type;
std::string key;
- OriginBoundCertService::RequestHandle request_handle;
- int rv = obc_service->GetOriginBoundCert(origin, requested_cert_types,
+ ServerBoundCertService::RequestHandle request_handle;
+ int rv = sbc_service->GetDomainBoundCert(origin, requested_cert_types,
&cert_type, &key, cert,
callback.callback(),
&request_handle);
@@ -279,7 +279,7 @@ void GetECOriginBoundCertAndProof(const std::string& origin,
std::vector<uint8> proof_data;
scoped_ptr<crypto::ECPrivateKey> private_key(
crypto::ECPrivateKey::CreateFromEncryptedPrivateKeyInfo(
- OriginBoundCertService::kEPKIPassword, key_data, spki));
+ ServerBoundCertService::kEPKIPassword, key_data, spki));
scoped_ptr<crypto::ECSignatureCreator> creator(
crypto::ECSignatureCreator::Create(private_key.get()));
creator->Sign(secret, arraysize(secret), &proof_data);
@@ -288,14 +288,14 @@ void GetECOriginBoundCertAndProof(const std::string& origin,
} // namespace
// TODO(rch): When openssl supports origin bound certifictes, this
// guard can be removed
#if !defined(USE_OPENSSL)
// Test that if we request a resource for a new origin on a session that
// used origin bound certificates, that we send a CREDENTIAL frame for
// the new origin before we send the new request.
void SpdyHttpStreamSpdy2Test::TestSendCredentials(
- OriginBoundCertService* obc_service,
+ ServerBoundCertService* sbc_service,
const std::string& cert,
const std::string& proof,
SSLClientCertType type) {
@@ -334,8 +334,8 @@ void SpdyHttpStreamSpdy2Test::TestSendCredentials(
writes, arraysize(writes)));
socket_factory->AddSocketDataProvider(data.get());
SSLSocketDataProvider ssl(SYNCHRONOUS, OK);
- ssl.origin_bound_cert_type = type;
- ssl.origin_bound_cert_service = obc_service;
+ ssl.domain_bound_cert_type = type;
+ ssl.server_bound_cert_service = sbc_service;
ssl.protocol_negotiated = SSLClientSocket::kProtoSPDY3;
socket_factory->AddSSLSocketDataProvider(&ssl);
http_session_ = SpdySessionDependencies::SpdyCreateSessionDeterministic(
@@ -288,14 +288,14 @@ void GetECOriginBoundCertAndProof(const std::string& origin,
} // namespace
-// TODO(rch): When openssl supports origin bound certifictes, this
+// TODO(rch): When openssl supports server bound certifictes, this
// guard can be removed
#if !defined(USE_OPENSSL)
@@ -288,14 +288,14 @@ void GetECOriginBoundCertAndProof(const std::string& origin,
// guard can be removed
#if !defined(USE_OPENSSL)
-// Test that if we request a resource for a new origin on a session that
-// used origin bound certificates, that we send a CREDENTIAL frame for
-// the new origin before we send the new request.
+// Test that if we request a resource for a new domain on a session that
+// used domain bound certificates, that we send a CREDENTIAL frame for
+// the new domain before we send the new request.
void SpdyHttpStreamSpdy2Test::TestSendCredentials(

Powered by Google App Engine
This is Rietveld 408576698